@@ -15,6 +15,7 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.agent;
 
+import java.io.File;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.concurrent.CountDownLatch;
@@ -39,7 +40,6 @@ import com.clustercontrol.agent.util.CollectorId;
 import com.clustercontrol.agent.util.CollectorManager;
 import com.clustercontrol.agent.util.CommandMonitoringWSUtil;
 import com.clustercontrol.agent.winevent.WinEventCollector;
-import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.jobmanagement.bean.CommandConstant;
 import com.clustercontrol.jobmanagement.bean.CommandStopTypeConstant;
 import com.clustercontrol.jobmanagement.bean.CommandTypeConstant;
@@ -286,6 +286,8 @@ public class ReceiveTopic extends Thread {
 				reloadWinEventMonitor(updateInfo, false);
 				reloadJobFileCheck(updateInfo, false);
 
+				settingLastUpdateInfo = updateInfo;
+
 				m_log.debug("getTopic " + Agent.getAgentStr() + " end");
 				if (runInstructionList.size() > 0) {
 					m_log.info("infoList.size() = " + runInstructionList.size());
@@ -406,14 +408,6 @@ public class ReceiveTopic extends Thread {
 				CollectorManager.registerCollectorTask(new CommandCollector(dto));
 			}
 
-			// update last update time
-			settingLastUpdateInfo = updateInfo;
-			if (updateInfo != null) {
-				m_log.info("command monitor updated. (custom = " + updateInfo.getCustomMonitorUpdateTime()
-						+ ", calendar = " + updateInfo.getCalendarUpdateTime()
-						+ ", repository = " + updateInfo.getRepositoryUpdateTime() + ")");
-			}
-
 		} catch (HinemosUnknown_Exception e) {
 			m_log.warn("un-expected internal failure occurs...", e);
 		} catch (CustomInvalid_Exception e) {
@@ -443,13 +437,6 @@ public class ReceiveTopic extends Thread {
 			}
 			LogfileMonitorManager.setLogfileMonitor(list);
 
-			// update last update time
-			settingLastUpdateInfo = updateInfo;
-			if (updateInfo != null) {
-				m_log.info("logfile monitor updated. (logfile = " + updateInfo.getLogFileMonitorUpdateTime()
-						+ ", calendar = " + updateInfo.getCalendarUpdateTime()
-						+ ", repository = " + updateInfo.getRepositoryUpdateTime() + ")");
-			}
 		} catch (HinemosUnknown_Exception e) {
 			m_log.error(e,e);
 		} catch (InvalidRole_Exception e) {
@@ -484,7 +471,10 @@ public class ReceiveTopic extends Thread {
 				CollectorManager.unregisterCollectorTask(collectId);
 			}
 
-			// reset WinEvent Collector
+			// reset WinEvent Collector and delete unnecessary lastrun files
+			File[] files = new File(WinEventCollector.runPath).listFiles();
+			ArrayList<String> necessaryLastrunList = new ArrayList<String>();
+			
 			for (MonitorInfo info : list) {
 				m_log.info("winevent: critical=" + info.getWinEventCheckInfo().isLevelCritical() +
 						", warning=" + info.getWinEventCheckInfo().isLevelWarning() +
@@ -493,22 +483,27 @@ public class ReceiveTopic extends Thread {
 						", informational=" + info.getWinEventCheckInfo().isLevelInformational() +
 						", monitorId=" + info.getMonitorId() +
 						", monitorFlg=" + info.getMonitorFlg());
-				if (info.getMonitorFlg() == ValidConstant.TYPE_INVALID) {
-					m_log.debug("WinEventMonitorThread(monitorId=" + info.getMonitorId()+ ") start is skipped because of monitor flg");
-					continue;
-				}
-
+				
+				// reset WinEvent Collector
 				CollectorManager.registerCollectorTask(new WinEventCollector(info, m_sendQueue));
+				
+				// register needed lastrun file
+				String lastrunFileName = WinEventCollector.PREFIX + info.getMonitorId() + WinEventCollector.POSTFIX_LASTRUN;
+				necessaryLastrunList.add(lastrunFileName);
 			}
-
-			// update last update time
-			settingLastUpdateInfo = updateInfo;
-			if (updateInfo != null) {
-				m_log.info("winevent monitor updated. (winevent = " + updateInfo.getWinEventMonitorUpdateTime()
-						+ ", calendar = " + updateInfo.getCalendarUpdateTime()
-						+ ", repository = " + updateInfo.getRepositoryUpdateTime() + ")");
+			
+			// delete unnecessary lastrun file
+			for(int i = 0; i < files.length; i++){
+				File file = files[i];
+				String fileName = file.getName();
+				if(fileName.endsWith(WinEventCollector.POSTFIX_LASTRUN) && !necessaryLastrunList.contains(fileName)){
+					m_log.info("deleted unnecessary lastrun file : " + fileName);
+					boolean deleted = file.delete();
+					if(!deleted){
+						m_log.error("could not delete lastrun file : " + fileName);
+					}
+				}
 			}
-
 		} catch (HinemosUnknown_Exception e) {
 			m_log.error(e,e);
 		} catch (InvalidRole_Exception e) {
@@ -518,7 +513,6 @@ public class ReceiveTopic extends Thread {
 		} catch (MonitorNotFound_Exception e) {
 			m_log.warn("realoadWinEventMonitor: " + e.getMessage());
 		}
-
 	}
 
 	private void reloadJobFileCheck (SettingUpdateInfo updateInfo, boolean force) {
