@@ -27,36 +27,42 @@ public class ObjectFactory {
     private final static QName _JobResult_QNAME = new QName("http://agent.ws.clustercontrol.com", "jobResult");
     private final static QName _FacilityNotFound_QNAME = new QName("http://agent.ws.clustercontrol.com", "FacilityNotFound");
     private final static QName _DeleteAgentResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "deleteAgentResponse");
-    private final static QName _Echo_QNAME = new QName("http://agent.ws.clustercontrol.com", "echo");
+    private final static QName _JobMasterNotFound_QNAME = new QName("http://agent.ws.clustercontrol.com", "JobMasterNotFound");
     private final static QName _PutCommandResultDTO_QNAME = new QName("http://agent.ws.clustercontrol.com", "putCommandResultDTO");
-    private final static QName _DeleteAgent_QNAME = new QName("http://agent.ws.clustercontrol.com", "deleteAgent");
+    private final static QName _Echo_QNAME = new QName("http://agent.ws.clustercontrol.com", "echo");
+    private final static QName _GetFileCheckForAgent_QNAME = new QName("http://agent.ws.clustercontrol.com", "getFileCheckForAgent");
     private final static QName _SendNotify_QNAME = new QName("http://agent.ws.clustercontrol.com", "sendNotify");
-    private final static QName _GetSettingUpdateInfoResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "getSettingUpdateInfoResponse");
+    private final static QName _DeleteAgent_QNAME = new QName("http://agent.ws.clustercontrol.com", "deleteAgent");
     private final static QName _JobInfoNotFound_QNAME = new QName("http://agent.ws.clustercontrol.com", "JobInfoNotFound");
     private final static QName _PutCommandResultDTOResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "putCommandResultDTOResponse");
     private final static QName _DownloadModule_QNAME = new QName("http://agent.ws.clustercontrol.com", "downloadModule");
+    private final static QName _GetFileCheckForAgentResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "getFileCheckForAgentResponse");
     private final static QName _GetMonitorLogfileResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "getMonitorLogfileResponse");
+    private final static QName _JobFileCheckResultResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "jobFileCheckResultResponse");
     private final static QName _SendMessage_QNAME = new QName("http://agent.ws.clustercontrol.com", "sendMessage");
     private final static QName _GetMonitorLogfile_QNAME = new QName("http://agent.ws.clustercontrol.com", "getMonitorLogfile");
     private final static QName _SetAgentLibMd5_QNAME = new QName("http://agent.ws.clustercontrol.com", "setAgentLibMd5");
-    private final static QName _GetTopicResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "getTopicResponse");
-    private final static QName _GetTopic_QNAME = new QName("http://agent.ws.clustercontrol.com", "getTopic");
+    private final static QName _JobSessionDuplicate_QNAME = new QName("http://agent.ws.clustercontrol.com", "JobSessionDuplicate");
     private final static QName _CustomInvalid_QNAME = new QName("http://agent.ws.clustercontrol.com", "CustomInvalid");
     private final static QName _HinemosUnknown_QNAME = new QName("http://agent.ws.clustercontrol.com", "HinemosUnknown");
     private final static QName _SetAgentLibMd5Response_QNAME = new QName("http://agent.ws.clustercontrol.com", "setAgentLibMd5Response");
-    private final static QName _GetSettingUpdateInfo_QNAME = new QName("http://agent.ws.clustercontrol.com", "getSettingUpdateInfo");
-    private final static QName _SendNotifyResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "sendNotifyResponse");
     private final static QName _GetAgentLibMapResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "getAgentLibMapResponse");
+    private final static QName _SendNotifyResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "sendNotifyResponse");
     private final static QName _InvalidUserPass_QNAME = new QName("http://agent.ws.clustercontrol.com", "InvalidUserPass");
     private final static QName _MonitorNotFound_QNAME = new QName("http://agent.ws.clustercontrol.com", "MonitorNotFound");
+    private final static QName _GetMonitorWinEvent_QNAME = new QName("http://agent.ws.clustercontrol.com", "getMonitorWinEvent");
+    private final static QName _GetHinemosTopicResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "getHinemosTopicResponse");
     private final static QName _GetCommandExecuteDTO_QNAME = new QName("http://agent.ws.clustercontrol.com", "getCommandExecuteDTO");
+    private final static QName _GetMonitorWinEventResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "getMonitorWinEventResponse");
+    private final static QName _GetHinemosTopic_QNAME = new QName("http://agent.ws.clustercontrol.com", "getHinemosTopic");
     private final static QName _GetCommandExecuteDTOResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "getCommandExecuteDTOResponse");
     private final static QName _GetAgentLibMap_QNAME = new QName("http://agent.ws.clustercontrol.com", "getAgentLibMap");
     private final static QName _EchoResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "echoResponse");
     private final static QName _InvalidRole_QNAME = new QName("http://agent.ws.clustercontrol.com", "InvalidRole");
-    private final static QName _JobResultResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "jobResultResponse");
     private final static QName _DownloadModuleResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "downloadModuleResponse");
+    private final static QName _JobResultResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "jobResultResponse");
     private final static QName _SendMessageResponse_QNAME = new QName("http://agent.ws.clustercontrol.com", "sendMessageResponse");
+    private final static QName _JobFileCheckResult_QNAME = new QName("http://agent.ws.clustercontrol.com", "jobFileCheckResult");
 
     /**
      * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: com.clustercontrol.ws.agent
@@ -65,326 +71,6 @@ public class ObjectFactory {
     public ObjectFactory() {
     }
 
-    /**
-     * Create an instance of {@link MonitorNotFound }
-     * 
-     */
-    public MonitorNotFound createMonitorNotFound() {
-        return new MonitorNotFound();
-    }
-
-    /**
-     * Create an instance of {@link CalendarDTO }
-     * 
-     */
-    public CalendarDTO createCalendarDTO() {
-        return new CalendarDTO();
-    }
-
-    /**
-     * Create an instance of {@link DownloadModule }
-     * 
-     */
-    public DownloadModule createDownloadModule() {
-        return new DownloadModule();
-    }
-
-    /**
-     * Create an instance of {@link SendMessage }
-     * 
-     */
-    public SendMessage createSendMessage() {
-        return new SendMessage();
-    }
-
-    /**
-     * Create an instance of {@link AgentOutputBasicInfo }
-     * 
-     */
-    public AgentOutputBasicInfo createAgentOutputBasicInfo() {
-        return new AgentOutputBasicInfo();
-    }
-
-    /**
-     * Create an instance of {@link SendMessageResponse }
-     * 
-     */
-    public SendMessageResponse createSendMessageResponse() {
-        return new SendMessageResponse();
-    }
-
-    /**
-     * Create an instance of {@link EchoResponse }
-     * 
-     */
-    public EchoResponse createEchoResponse() {
-        return new EchoResponse();
-    }
-
-    /**
-     * Create an instance of {@link DownloadModuleResponse }
-     * 
-     */
-    public DownloadModuleResponse createDownloadModuleResponse() {
-        return new DownloadModuleResponse();
-    }
-
-    /**
-     * Create an instance of {@link CalendarIrregularDTO }
-     * 
-     */
-    public CalendarIrregularDTO createCalendarIrregularDTO() {
-        return new CalendarIrregularDTO();
-    }
-
-    /**
-     * Create an instance of {@link CustomInvalid }
-     * 
-     */
-    public CustomInvalid createCustomInvalid() {
-        return new CustomInvalid();
-    }
-
-    /**
-     * Create an instance of {@link PutCommandResultDTO }
-     * 
-     */
-    public PutCommandResultDTO createPutCommandResultDTO() {
-        return new PutCommandResultDTO();
-    }
-
-    /**
-     * Create an instance of {@link GetTopicResponse }
-     * 
-     */
-    public GetTopicResponse createGetTopicResponse() {
-        return new GetTopicResponse();
-    }
-
-    /**
-     * Create an instance of {@link GetSettingUpdateInfo }
-     * 
-     */
-    public GetSettingUpdateInfo createGetSettingUpdateInfo() {
-        return new GetSettingUpdateInfo();
-    }
-
-    /**
-     * Create an instance of {@link JobResultResponse }
-     * 
-     */
-    public JobResultResponse createJobResultResponse() {
-        return new JobResultResponse();
-    }
-
-    /**
-     * Create an instance of {@link DeleteAgentResponse }
-     * 
-     */
-    public DeleteAgentResponse createDeleteAgentResponse() {
-        return new DeleteAgentResponse();
-    }
-
-    /**
-     * Create an instance of {@link GetCommandExecuteDTOResponse }
-     * 
-     */
-    public GetCommandExecuteDTOResponse createGetCommandExecuteDTOResponse() {
-        return new GetCommandExecuteDTOResponse();
-    }
-
-    /**
-     * Create an instance of {@link InvalidUserPass }
-     * 
-     */
-    public InvalidUserPass createInvalidUserPass() {
-        return new InvalidUserPass();
-    }
-
-    /**
-     * Create an instance of {@link SetAgentLibMd5 }
-     * 
-     */
-    public SetAgentLibMd5 createSetAgentLibMd5() {
-        return new SetAgentLibMd5();
-    }
-
-    /**
-     * Create an instance of {@link GetSettingUpdateInfoResponse }
-     * 
-     */
-    public GetSettingUpdateInfoResponse createGetSettingUpdateInfoResponse() {
-        return new GetSettingUpdateInfoResponse();
-    }
-
-    /**
-     * Create an instance of {@link MessageInfo }
-     * 
-     */
-    public MessageInfo createMessageInfo() {
-        return new MessageInfo();
-    }
-
-    /**
-     * Create an instance of {@link GetMonitorLogfileResponse }
-     * 
-     */
-    public GetMonitorLogfileResponse createGetMonitorLogfileResponse() {
-        return new GetMonitorLogfileResponse();
-    }
-
-    /**
-     * Create an instance of {@link PutCommandResultDTOResponse }
-     * 
-     */
-    public PutCommandResultDTOResponse createPutCommandResultDTOResponse() {
-        return new PutCommandResultDTOResponse();
-    }
-
-    /**
-     * Create an instance of {@link GetAgentLibMap }
-     * 
-     */
-    public GetAgentLibMap createGetAgentLibMap() {
-        return new GetAgentLibMap();
-    }
-
-    /**
-     * Create an instance of {@link SettingUpdateInfo }
-     * 
-     */
-    public SettingUpdateInfo createSettingUpdateInfo() {
-        return new SettingUpdateInfo();
-    }
-
-    /**
-     * Create an instance of {@link SendNotify }
-     * 
-     */
-    public SendNotify createSendNotify() {
-        return new SendNotify();
-    }
-
-    /**
-     * Create an instance of {@link JobInfoNotFound }
-     * 
-     */
-    public JobInfoNotFound createJobInfoNotFound() {
-        return new JobInfoNotFound();
-    }
-
-    /**
-     * Create an instance of {@link GetCommandExecuteDTO }
-     * 
-     */
-    public GetCommandExecuteDTO createGetCommandExecuteDTO() {
-        return new GetCommandExecuteDTO();
-    }
-
-    /**
-     * Create an instance of {@link CalendarWeekdayDTO }
-     * 
-     */
-    public CalendarWeekdayDTO createCalendarWeekdayDTO() {
-        return new CalendarWeekdayDTO();
-    }
-
-    /**
-     * Create an instance of {@link GetTopic }
-     * 
-     */
-    public GetTopic createGetTopic() {
-        return new GetTopic();
-    }
-
-    /**
-     * Create an instance of {@link FacilityNotFound }
-     * 
-     */
-    public FacilityNotFound createFacilityNotFound() {
-        return new FacilityNotFound();
-    }
-
-    /**
-     * Create an instance of {@link OutputBasicInfo }
-     * 
-     */
-    public OutputBasicInfo createOutputBasicInfo() {
-        return new OutputBasicInfo();
-    }
-
-    /**
-     * Create an instance of {@link InvalidRole }
-     * 
-     */
-    public InvalidRole createInvalidRole() {
-        return new InvalidRole();
-    }
-
-    /**
-     * Create an instance of {@link SetAgentLibMd5Response }
-     * 
-     */
-    public SetAgentLibMd5Response createSetAgentLibMd5Response() {
-        return new SetAgentLibMd5Response();
-    }
-
-    /**
-     * Create an instance of {@link HinemosUnknown }
-     * 
-     */
-    public HinemosUnknown createHinemosUnknown() {
-        return new HinemosUnknown();
-    }
-
-    /**
-     * Create an instance of {@link JobResult }
-     * 
-     */
-    public JobResult createJobResult() {
-        return new JobResult();
-    }
-
-    /**
-     * Create an instance of {@link AgentInfo }
-     * 
-     */
-    public AgentInfo createAgentInfo() {
-        return new AgentInfo();
-    }
-
-    /**
-     * Create an instance of {@link GetAgentLibMapResponse }
-     * 
-     */
-    public GetAgentLibMapResponse createGetAgentLibMapResponse() {
-        return new GetAgentLibMapResponse();
-    }
-
-    /**
-     * Create an instance of {@link SendNotifyResponse }
-     * 
-     */
-    public SendNotifyResponse createSendNotifyResponse() {
-        return new SendNotifyResponse();
-    }
-
-    /**
-     * Create an instance of {@link TopicInfo }
-     * 
-     */
-    public TopicInfo createTopicInfo() {
-        return new TopicInfo();
-    }
-
-    /**
-     * Create an instance of {@link Echo }
-     * 
-     */
-    public Echo createEcho() {
-        return new Echo();
-    }
-
     /**
      * Create an instance of {@link DeleteAgent }
      * 
@@ -393,6 +79,86 @@ public class ObjectFactory {
         return new DeleteAgent();
     }
 
+    /**
+     * Create an instance of {@link SendNotify }
+     * 
+     */
+    public SendNotify createSendNotify() {
+        return new SendNotify();
+    }
+
+    /**
+     * Create an instance of {@link GetFileCheckForAgent }
+     * 
+     */
+    public GetFileCheckForAgent createGetFileCheckForAgent() {
+        return new GetFileCheckForAgent();
+    }
+
+    /**
+     * Create an instance of {@link FacilityNotFound }
+     * 
+     */
+    public FacilityNotFound createFacilityNotFound() {
+        return new FacilityNotFound();
+    }
+
+    /**
+     * Create an instance of {@link JobResult }
+     * 
+     */
+    public JobResult createJobResult() {
+        return new JobResult();
+    }
+
+    /**
+     * Create an instance of {@link DeleteAgentResponse }
+     * 
+     */
+    public DeleteAgentResponse createDeleteAgentResponse() {
+        return new DeleteAgentResponse();
+    }
+
+    /**
+     * Create an instance of {@link Echo }
+     * 
+     */
+    public Echo createEcho() {
+        return new Echo();
+    }
+
+    /**
+     * Create an instance of {@link PutCommandResultDTO }
+     * 
+     */
+    public PutCommandResultDTO createPutCommandResultDTO() {
+        return new PutCommandResultDTO();
+    }
+
+    /**
+     * Create an instance of {@link JobMasterNotFound }
+     * 
+     */
+    public JobMasterNotFound createJobMasterNotFound() {
+        return new JobMasterNotFound();
+    }
+
+    /**
+     * Create an instance of {@link SendMessage }
+     * 
+     */
+    public SendMessage createSendMessage() {
+        return new SendMessage();
+    }
+
+    /**
+     * Create an instance of {@link JobFileCheckResultResponse }
+     * 
+     */
+    public JobFileCheckResultResponse createJobFileCheckResultResponse() {
+        return new JobFileCheckResultResponse();
+    }
+
     /**
      * Create an instance of {@link GetMonitorLogfile }
      * 
@@ -401,6 +167,278 @@ public class ObjectFactory {
         return new GetMonitorLogfile();
     }
 
+    /**
+     * Create an instance of {@link SetAgentLibMd5 }
+     * 
+     */
+    public SetAgentLibMd5 createSetAgentLibMd5() {
+        return new SetAgentLibMd5();
+    }
+
+    /**
+     * Create an instance of {@link JobSessionDuplicate }
+     * 
+     */
+    public JobSessionDuplicate createJobSessionDuplicate() {
+        return new JobSessionDuplicate();
+    }
+
+    /**
+     * Create an instance of {@link JobInfoNotFound }
+     * 
+     */
+    public JobInfoNotFound createJobInfoNotFound() {
+        return new JobInfoNotFound();
+    }
+
+    /**
+     * Create an instance of {@link PutCommandResultDTOResponse }
+     * 
+     */
+    public PutCommandResultDTOResponse createPutCommandResultDTOResponse() {
+        return new PutCommandResultDTOResponse();
+    }
+
+    /**
+     * Create an instance of {@link DownloadModule }
+     * 
+     */
+    public DownloadModule createDownloadModule() {
+        return new DownloadModule();
+    }
+
+    /**
+     * Create an instance of {@link GetFileCheckForAgentResponse }
+     * 
+     */
+    public GetFileCheckForAgentResponse createGetFileCheckForAgentResponse() {
+        return new GetFileCheckForAgentResponse();
+    }
+
+    /**
+     * Create an instance of {@link GetMonitorLogfileResponse }
+     * 
+     */
+    public GetMonitorLogfileResponse createGetMonitorLogfileResponse() {
+        return new GetMonitorLogfileResponse();
+    }
+
+    /**
+     * Create an instance of {@link MonitorNotFound }
+     * 
+     */
+    public MonitorNotFound createMonitorNotFound() {
+        return new MonitorNotFound();
+    }
+
+    /**
+     * Create an instance of {@link InvalidUserPass }
+     * 
+     */
+    public InvalidUserPass createInvalidUserPass() {
+        return new InvalidUserPass();
+    }
+
+    /**
+     * Create an instance of {@link GetHinemosTopicResponse }
+     * 
+     */
+    public GetHinemosTopicResponse createGetHinemosTopicResponse() {
+        return new GetHinemosTopicResponse();
+    }
+
+    /**
+     * Create an instance of {@link GetCommandExecuteDTO }
+     * 
+     */
+    public GetCommandExecuteDTO createGetCommandExecuteDTO() {
+        return new GetCommandExecuteDTO();
+    }
+
+    /**
+     * Create an instance of {@link GetMonitorWinEventResponse }
+     * 
+     */
+    public GetMonitorWinEventResponse createGetMonitorWinEventResponse() {
+        return new GetMonitorWinEventResponse();
+    }
+
+    /**
+     * Create an instance of {@link GetMonitorWinEvent }
+     * 
+     */
+    public GetMonitorWinEvent createGetMonitorWinEvent() {
+        return new GetMonitorWinEvent();
+    }
+
+    /**
+     * Create an instance of {@link HinemosUnknown }
+     * 
+     */
+    public HinemosUnknown createHinemosUnknown() {
+        return new HinemosUnknown();
+    }
+
+    /**
+     * Create an instance of {@link CustomInvalid }
+     * 
+     */
+    public CustomInvalid createCustomInvalid() {
+        return new CustomInvalid();
+    }
+
+    /**
+     * Create an instance of {@link SendNotifyResponse }
+     * 
+     */
+    public SendNotifyResponse createSendNotifyResponse() {
+        return new SendNotifyResponse();
+    }
+
+    /**
+     * Create an instance of {@link GetAgentLibMapResponse }
+     * 
+     */
+    public GetAgentLibMapResponse createGetAgentLibMapResponse() {
+        return new GetAgentLibMapResponse();
+    }
+
+    /**
+     * Create an instance of {@link SetAgentLibMd5Response }
+     * 
+     */
+    public SetAgentLibMd5Response createSetAgentLibMd5Response() {
+        return new SetAgentLibMd5Response();
+    }
+
+    /**
+     * Create an instance of {@link InvalidRole }
+     * 
+     */
+    public InvalidRole createInvalidRole() {
+        return new InvalidRole();
+    }
+
+    /**
+     * Create an instance of {@link SendMessageResponse }
+     * 
+     */
+    public SendMessageResponse createSendMessageResponse() {
+        return new SendMessageResponse();
+    }
+
+    /**
+     * Create an instance of {@link JobResultResponse }
+     * 
+     */
+    public JobResultResponse createJobResultResponse() {
+        return new JobResultResponse();
+    }
+
+    /**
+     * Create an instance of {@link DownloadModuleResponse }
+     * 
+     */
+    public DownloadModuleResponse createDownloadModuleResponse() {
+        return new DownloadModuleResponse();
+    }
+
+    /**
+     * Create an instance of {@link JobFileCheckResult }
+     * 
+     */
+    public JobFileCheckResult createJobFileCheckResult() {
+        return new JobFileCheckResult();
+    }
+
+    /**
+     * Create an instance of {@link GetCommandExecuteDTOResponse }
+     * 
+     */
+    public GetCommandExecuteDTOResponse createGetCommandExecuteDTOResponse() {
+        return new GetCommandExecuteDTOResponse();
+    }
+
+    /**
+     * Create an instance of {@link GetHinemosTopic }
+     * 
+     */
+    public GetHinemosTopic createGetHinemosTopic() {
+        return new GetHinemosTopic();
+    }
+
+    /**
+     * Create an instance of {@link GetAgentLibMap }
+     * 
+     */
+    public GetAgentLibMap createGetAgentLibMap() {
+        return new GetAgentLibMap();
+    }
+
+    /**
+     * Create an instance of {@link EchoResponse }
+     * 
+     */
+    public EchoResponse createEchoResponse() {
+        return new EchoResponse();
+    }
+
+    /**
+     * Create an instance of {@link TopicInfo }
+     * 
+     */
+    public TopicInfo createTopicInfo() {
+        return new TopicInfo();
+    }
+
+    /**
+     * Create an instance of {@link SettingUpdateInfo }
+     * 
+     */
+    public SettingUpdateInfo createSettingUpdateInfo() {
+        return new SettingUpdateInfo();
+    }
+
+    /**
+     * Create an instance of {@link AgentOutputBasicInfo }
+     * 
+     */
+    public AgentOutputBasicInfo createAgentOutputBasicInfo() {
+        return new AgentOutputBasicInfo();
+    }
+
+    /**
+     * Create an instance of {@link MessageInfo }
+     * 
+     */
+    public MessageInfo createMessageInfo() {
+        return new MessageInfo();
+    }
+
+    /**
+     * Create an instance of {@link OutputBasicInfo }
+     * 
+     */
+    public OutputBasicInfo createOutputBasicInfo() {
+        return new OutputBasicInfo();
+    }
+
+    /**
+     * Create an instance of {@link AgentInfo }
+     * 
+     */
+    public AgentInfo createAgentInfo() {
+        return new AgentInfo();
+    }
+
+    /**
+     * Create an instance of {@link HinemosTopicInfo }
+     * 
+     */
+    public HinemosTopicInfo createHinemosTopicInfo() {
+        return new HinemosTopicInfo();
+    }
+
     /**
      * Create an instance of {@link JAXBElement }{@code <}{@link JobResult }{@code >}}
      * 
@@ -429,12 +467,12 @@ public class ObjectFactory {
     }
 
     /**
-     * Create an instance of {@link JAXBElement }{@code <}{@link Echo }{@code >}}
+     * Create an instance of {@link JAXBElement }{@code <}{@link JobMasterNotFound }{@code >}}
      * 
      */
-    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "echo")
-    public JAXBElement<Echo> createEcho(Echo value) {
-        return new JAXBElement<Echo>(_Echo_QNAME, Echo.class, null, value);
+    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "JobMasterNotFound")
+    public JAXBElement<JobMasterNotFound> createJobMasterNotFound(JobMasterNotFound value) {
+        return new JAXBElement<JobMasterNotFound>(_JobMasterNotFound_QNAME, JobMasterNotFound.class, null, value);
     }
 
     /**
@@ -447,12 +485,21 @@ public class ObjectFactory {
     }
 
     /**
-     * Create an instance of {@link JAXBElement }{@code <}{@link DeleteAgent }{@code >}}
+     * Create an instance of {@link JAXBElement }{@code <}{@link Echo }{@code >}}
      * 
      */
-    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "deleteAgent")
-    public JAXBElement<DeleteAgent> createDeleteAgent(DeleteAgent value) {
-        return new JAXBElement<DeleteAgent>(_DeleteAgent_QNAME, DeleteAgent.class, null, value);
+    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "echo")
+    public JAXBElement<Echo> createEcho(Echo value) {
+        return new JAXBElement<Echo>(_Echo_QNAME, Echo.class, null, value);
+    }
+
+    /**
+     * Create an instance of {@link JAXBElement }{@code <}{@link GetFileCheckForAgent }{@code >}}
+     * 
+     */
+    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "getFileCheckForAgent")
+    public JAXBElement<GetFileCheckForAgent> createGetFileCheckForAgent(GetFileCheckForAgent value) {
+        return new JAXBElement<GetFileCheckForAgent>(_GetFileCheckForAgent_QNAME, GetFileCheckForAgent.class, null, value);
     }
 
     /**
@@ -465,12 +512,12 @@ public class ObjectFactory {
     }
 
     /**
-     * Create an instance of {@link JAXBElement }{@code <}{@link GetSettingUpdateInfoResponse }{@code >}}
+     * Create an instance of {@link JAXBElement }{@code <}{@link DeleteAgent }{@code >}}
      * 
      */
-    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "getSettingUpdateInfoResponse")
-    public JAXBElement<GetSettingUpdateInfoResponse> createGetSettingUpdateInfoResponse(GetSettingUpdateInfoResponse value) {
-        return new JAXBElement<GetSettingUpdateInfoResponse>(_GetSettingUpdateInfoResponse_QNAME, GetSettingUpdateInfoResponse.class, null, value);
+    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "deleteAgent")
+    public JAXBElement<DeleteAgent> createDeleteAgent(DeleteAgent value) {
+        return new JAXBElement<DeleteAgent>(_DeleteAgent_QNAME, DeleteAgent.class, null, value);
     }
 
     /**
@@ -500,6 +547,15 @@ public class ObjectFactory {
         return new JAXBElement<DownloadModule>(_DownloadModule_QNAME, DownloadModule.class, null, value);
     }
 
+    /**
+     * Create an instance of {@link JAXBElement }{@code <}{@link GetFileCheckForAgentResponse }{@code >}}
+     * 
+     */
+    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "getFileCheckForAgentResponse")
+    public JAXBElement<GetFileCheckForAgentResponse> createGetFileCheckForAgentResponse(GetFileCheckForAgentResponse value) {
+        return new JAXBElement<GetFileCheckForAgentResponse>(_GetFileCheckForAgentResponse_QNAME, GetFileCheckForAgentResponse.class, null, value);
+    }
+
     /**
      * Create an instance of {@link JAXBElement }{@code <}{@link GetMonitorLogfileResponse }{@code >}}
      * 
@@ -509,6 +565,15 @@ public class ObjectFactory {
         return new JAXBElement<GetMonitorLogfileResponse>(_GetMonitorLogfileResponse_QNAME, GetMonitorLogfileResponse.class, null, value);
     }
 
+    /**
+     * Create an instance of {@link JAXBElement }{@code <}{@link JobFileCheckResultResponse }{@code >}}
+     * 
+     */
+    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "jobFileCheckResultResponse")
+    public JAXBElement<JobFileCheckResultResponse> createJobFileCheckResultResponse(JobFileCheckResultResponse value) {
+        return new JAXBElement<JobFileCheckResultResponse>(_JobFileCheckResultResponse_QNAME, JobFileCheckResultResponse.class, null, value);
+    }
+
     /**
      * Create an instance of {@link JAXBElement }{@code <}{@link SendMessage }{@code >}}
      * 
@@ -537,21 +602,12 @@ public class ObjectFactory {
     }
 
     /**
-     * Create an instance of {@link JAXBElement }{@code <}{@link GetTopicResponse }{@code >}}
+     * Create an instance of {@link JAXBElement }{@code <}{@link JobSessionDuplicate }{@code >}}
      * 
      */
-    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "getTopicResponse")
-    public JAXBElement<GetTopicResponse> createGetTopicResponse(GetTopicResponse value) {
-        return new JAXBElement<GetTopicResponse>(_GetTopicResponse_QNAME, GetTopicResponse.class, null, value);
-    }
-
-    /**
-     * Create an instance of {@link JAXBElement }{@code <}{@link GetTopic }{@code >}}
-     * 
-     */
-    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "getTopic")
-    public JAXBElement<GetTopic> createGetTopic(GetTopic value) {
-        return new JAXBElement<GetTopic>(_GetTopic_QNAME, GetTopic.class, null, value);
+    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "JobSessionDuplicate")
+    public JAXBElement<JobSessionDuplicate> createJobSessionDuplicate(JobSessionDuplicate value) {
+        return new JAXBElement<JobSessionDuplicate>(_JobSessionDuplicate_QNAME, JobSessionDuplicate.class, null, value);
     }
 
     /**
@@ -582,12 +638,12 @@ public class ObjectFactory {
     }
 
     /**
-     * Create an instance of {@link JAXBElement }{@code <}{@link GetSettingUpdateInfo }{@code >}}
+     * Create an instance of {@link JAXBElement }{@code <}{@link GetAgentLibMapResponse }{@code >}}
      * 
      */
-    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "getSettingUpdateInfo")
-    public JAXBElement<GetSettingUpdateInfo> createGetSettingUpdateInfo(GetSettingUpdateInfo value) {
-        return new JAXBElement<GetSettingUpdateInfo>(_GetSettingUpdateInfo_QNAME, GetSettingUpdateInfo.class, null, value);
+    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "getAgentLibMapResponse")
+    public JAXBElement<GetAgentLibMapResponse> createGetAgentLibMapResponse(GetAgentLibMapResponse value) {
+        return new JAXBElement<GetAgentLibMapResponse>(_GetAgentLibMapResponse_QNAME, GetAgentLibMapResponse.class, null, value);
     }
 
     /**
@@ -599,15 +655,6 @@ public class ObjectFactory {
         return new JAXBElement<SendNotifyResponse>(_SendNotifyResponse_QNAME, SendNotifyResponse.class, null, value);
     }
 
-    /**
-     * Create an instance of {@link JAXBElement }{@code <}{@link GetAgentLibMapResponse }{@code >}}
-     * 
-     */
-    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "getAgentLibMapResponse")
-    public JAXBElement<GetAgentLibMapResponse> createGetAgentLibMapResponse(GetAgentLibMapResponse value) {
-        return new JAXBElement<GetAgentLibMapResponse>(_GetAgentLibMapResponse_QNAME, GetAgentLibMapResponse.class, null, value);
-    }
-
     /**
      * Create an instance of {@link JAXBElement }{@code <}{@link InvalidUserPass }{@code >}}
      * 
@@ -626,6 +673,24 @@ public class ObjectFactory {
         return new JAXBElement<MonitorNotFound>(_MonitorNotFound_QNAME, MonitorNotFound.class, null, value);
     }
 
+    /**
+     * Create an instance of {@link JAXBElement }{@code <}{@link GetMonitorWinEvent }{@code >}}
+     * 
+     */
+    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "getMonitorWinEvent")
+    public JAXBElement<GetMonitorWinEvent> createGetMonitorWinEvent(GetMonitorWinEvent value) {
+        return new JAXBElement<GetMonitorWinEvent>(_GetMonitorWinEvent_QNAME, GetMonitorWinEvent.class, null, value);
+    }
+
+    /**
+     * Create an instance of {@link JAXBElement }{@code <}{@link GetHinemosTopicResponse }{@code >}}
+     * 
+     */
+    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "getHinemosTopicResponse")
+    public JAXBElement<GetHinemosTopicResponse> createGetHinemosTopicResponse(GetHinemosTopicResponse value) {
+        return new JAXBElement<GetHinemosTopicResponse>(_GetHinemosTopicResponse_QNAME, GetHinemosTopicResponse.class, null, value);
+    }
+
     /**
      * Create an instance of {@link JAXBElement }{@code <}{@link GetCommandExecuteDTO }{@code >}}
      * 
@@ -635,6 +700,24 @@ public class ObjectFactory {
         return new JAXBElement<GetCommandExecuteDTO>(_GetCommandExecuteDTO_QNAME, GetCommandExecuteDTO.class, null, value);
     }
 
+    /**
+     * Create an instance of {@link JAXBElement }{@code <}{@link GetMonitorWinEventResponse }{@code >}}
+     * 
+     */
+    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "getMonitorWinEventResponse")
+    public JAXBElement<GetMonitorWinEventResponse> createGetMonitorWinEventResponse(GetMonitorWinEventResponse value) {
+        return new JAXBElement<GetMonitorWinEventResponse>(_GetMonitorWinEventResponse_QNAME, GetMonitorWinEventResponse.class, null, value);
+    }
+
+    /**
+     * Create an instance of {@link JAXBElement }{@code <}{@link GetHinemosTopic }{@code >}}
+     * 
+     */
+    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "getHinemosTopic")
+    public JAXBElement<GetHinemosTopic> createGetHinemosTopic(GetHinemosTopic value) {
+        return new JAXBElement<GetHinemosTopic>(_GetHinemosTopic_QNAME, GetHinemosTopic.class, null, value);
+    }
+
     /**
      * Create an instance of {@link JAXBElement }{@code <}{@link GetCommandExecuteDTOResponse }{@code >}}
      * 
@@ -671,15 +754,6 @@ public class ObjectFactory {
         return new JAXBElement<InvalidRole>(_InvalidRole_QNAME, InvalidRole.class, null, value);
     }
 
-    /**
-     * Create an instance of {@link JAXBElement }{@code <}{@link JobResultResponse }{@code >}}
-     * 
-     */
-    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "jobResultResponse")
-    public JAXBElement<JobResultResponse> createJobResultResponse(JobResultResponse value) {
-        return new JAXBElement<JobResultResponse>(_JobResultResponse_QNAME, JobResultResponse.class, null, value);
-    }
-
     /**
      * Create an instance of {@link JAXBElement }{@code <}{@link DownloadModuleResponse }{@code >}}
      * 
@@ -689,6 +763,15 @@ public class ObjectFactory {
         return new JAXBElement<DownloadModuleResponse>(_DownloadModuleResponse_QNAME, DownloadModuleResponse.class, null, value);
     }
 
+    /**
+     * Create an instance of {@link JAXBElement }{@code <}{@link JobResultResponse }{@code >}}
+     * 
+     */
+    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "jobResultResponse")
+    public JAXBElement<JobResultResponse> createJobResultResponse(JobResultResponse value) {
+        return new JAXBElement<JobResultResponse>(_JobResultResponse_QNAME, JobResultResponse.class, null, value);
+    }
+
     /**
      * Create an instance of {@link JAXBElement }{@code <}{@link SendMessageResponse }{@code >}}
      * 
@@ -698,4 +781,13 @@ public class ObjectFactory {
         return new JAXBElement<SendMessageResponse>(_SendMessageResponse_QNAME, SendMessageResponse.class, null, value);
     }
 
+    /**
+     * Create an instance of {@link JAXBElement }{@code <}{@link JobFileCheckResult }{@code >}}
+     * 
+     */
+    @XmlElementDecl(namespace = "http://agent.ws.clustercontrol.com", name = "jobFileCheckResult")
+    public JAXBElement<JobFileCheckResult> createJobFileCheckResult(JobFileCheckResult value) {
+        return new JAXBElement<JobFileCheckResult>(_JobFileCheckResult_QNAME, JobFileCheckResult.class, null, value);
+    }
+
 }
