@@ -30,11 +30,11 @@ public class ObjectFactory {
     }
 
     /**
-     * Create an instance of {@link RunInfo }
+     * Create an instance of {@link JobFileCheck }
      * 
      */
-    public RunInfo createRunInfo() {
-        return new RunInfo();
+    public JobFileCheck createJobFileCheck() {
+        return new JobFileCheck();
     }
 
     /**
@@ -45,6 +45,22 @@ public class ObjectFactory {
         return new RunInstructionInfo();
     }
 
+    /**
+     * Create an instance of {@link JobKick }
+     * 
+     */
+    public JobKick createJobKick() {
+        return new JobKick();
+    }
+
+    /**
+     * Create an instance of {@link RunInfo }
+     * 
+     */
+    public RunInfo createRunInfo() {
+        return new RunInfo();
+    }
+
     /**
      * Create an instance of {@link RunResultInfo }
      * 
